==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/GridDataCommittedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceAggregatedResultDescriptionMetadata } from "./DataSourceAggregatedResultDescriptionMetadata";
import { GridDataCommittedEventArgsDescription } from "./GridDataCommittedEventArgsDescription";
/**
 * @hidden
 */
var GridDataCommittedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridDataCommittedEventArgsDescriptionMetadata, _super);
    function GridDataCommittedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridDataCommittedEventArgsDescriptionMetadata.b = function (a) {
        if (GridDataCommittedEventArgsDescriptionMetadata.a == null) {
            GridDataCommittedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridDataCommittedEventArgsDescriptionMetadata.c(GridDataCommittedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridDataCommittedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(GridDataCommittedEventArgsDescriptionMetadata.a);
        DataSourceAggregatedResultDescriptionMetadata.d(a);
    };
    GridDataCommittedEventArgsDescriptionMetadata.c = function (a) {
        a.item("CommitID", "Number:int");
        a.item("Changes", "Array:DataSourceAggregatedResultDescription:DataSourceAggregatedResult");
    };
    GridDataCommittedEventArgsDescriptionMetadata.d = function (a) {
        GridDataCommittedEventArgsDescriptionMetadata.b(a);
        a.ad("GridDataCommittedEventArgs", function () { return new GridDataCommittedEventArgsDescription(); });
        a.ac("GridDataCommittedEventArgs", GridDataCommittedEventArgsDescriptionMetadata.a);
    };
    GridDataCommittedEventArgsDescriptionMetadata.$t = markType(GridDataCommittedEventArgsDescriptionMetadata, 'GridDataCommittedEventArgsDescriptionMetadata');
    GridDataCommittedEventArgsDescriptionMetadata.a = null;
    return GridDataCommittedEventArgsDescriptionMetadata;
}(Base));
export { GridDataCommittedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/GridDataCommittedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceAggregatedResultDescriptionMetadata } from "./DataSourceAggregatedResultDescriptionMetadata";
import { GridDataCommittedEventArgsDescription } from "./GridDataCommittedEventArgsDescription";
/**
 * @hidden
 */
var GridDataCommittedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridDataCommittedEventArgsDescriptionMetadata, _super);
    function GridDataCommittedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridDataCommittedEventArgsDescriptionMetadata.b = function (a) {
        if (GridDataCommittedEventArgsDescriptionMetadata.a == null) {
            GridDataCommittedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridDataCommittedEventArgsDescriptionMetadata.c(GridDataCommittedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridDataCommittedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(GridDataCommittedEventArgsDescriptionMetadata.a);
        DataSourceAggregatedResultDescriptionMetadata.d(a);
    };
    GridDataCommittedEventArgsDescriptionMetadata.c = function (a) {
        a.item("CommitID", "Number:int");
        a.item("Changes", "Array:DataSourceAggregatedResultDescription:DataSourceAggregatedResult");
    };
    GridDataCommittedEventArgsDescriptionMetadata.d = function (a) {
        GridDataCommittedEventArgsDescriptionMetadata.b(a);
        a.ae("GridDataCommittedEventArgs", function () { return new GridDataCommittedEventArgsDescription(); });
        a.ad("GridDataCommittedEventArgs", GridDataCommittedEventArgsDescriptionMetadata.a);
    };
    GridDataCommittedEventArgsDescriptionMetadata.$t = markType(GridDataCommittedEventArgsDescriptionMetadata, 'GridDataCommittedEventArgsDescriptionMetadata');
    GridDataCommittedEventArgsDescriptionMetadata.a = null;
    return GridDataCommittedEventArgsDescriptionMetadata;
}(Base));
export { GridDataCommittedEventArgsDescriptionMetadata };
